/*
 * Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
 * Copyright (C) 2007 - INRIA - Allan CORNET
 * 
 * This file must be used under the terms of the CeCILL.
 * This source file is licensed as described in the file COPYING, which
 * you should have received as part of this distribution.  The terms
 * are also available at    
 * http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
 *
 */
/*--------------------------------------------------------------------------*/ 
#ifndef __MORE_H__
#define __MORE_H__

#include "dynlib_shell.h"

/**
* do a "more" 
* @return 0 or 1 
*/
SHELL_IMPEXP int linesmore(void);

#endif /*  __MORE_H__ */
/*--------------------------------------------------------------------------*/ 
